==> iamport_flutter-0.10.6.tar.gz: SUPPORT.md <==
# 지원정보
아임포트 플러터 모듈이 지원하는 PG사 및 결제수단 안내입니다.

| pg           | 이름                  | 결제수단                                                                                          |
|--------------|---------------------|-----------------------------------------------------------------------------------------------|
| html5_inicis | 웹 표준 이니시스           | 신용카드, 가상계좌, 실시간 계좌이체(IOS 별도 설정 필요), 휴대폰 소액결제, 삼성페이, KPAY, 문화상품권, 스마트문상, 해피머니                  |
| kcp          | NHN KCP             | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제, 삼성페이                                                          |
| kcp_billing  | NHN KCP 정기결제        | 신용카드                                                                                          |
| uplus        | 토스페이먼츠 - (구)LG 유플러스 | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제, 문화상품권, 스마트문상, 도서상푼권                                           |                |
| jtnet        | JTNET               | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제                                                                |
| nice         | 나이스 정보통신            | 신용카드, 가상계좌, 실시간 계좌이체(IOS/안드로이드 별도 설정 필요), 휴대폰 소액결제                                            |
| kakaopay     | 신 - 카카오페이           | 신용카드                                                                                          |
| kakao        | 구 - LG CNS 카카오페이    | 신용카드                                                                                          |
| danal        | 다날 휴대폰 소액결제         | 휴대폰 소액결제                                                                                      |
| danal_tpay   | 다날 일반결제             | 신용카드, 가상계좌, 실시간 계좌이체                                                                          |
| kicc         | 한국정보통신              | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제                                                                |
| paypal       | 페이팔                 | 신용카드                                                                                          |
| mobilians    | 모빌리언스               | 신용카드, 가상계좌(준비중), 실시간 계좌이체(준비중), 휴대폰 소액결제                                                      |
| payco        | 페이코                 | 신용카드                                                                                          |
| eximbay      | 엑심베이                | 신용카드 [주의사항](https://github.com/iamport/iamport-react-native/issues/70#issuecomment-704601908) |
| settle       | 세틀뱅크                | 가상계좌                                                                                          |
| naverco      | 네이버 체크아웃            | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제                                                                |
| naverpay     | 네이버페이               | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제                                                                |
| smilepay     | 스마일페이               | 신용카드 [주의사항](https://github.com/iamport/iamport-react-native/issues/71)                        |
| chai         | 차이페이                | 신용카드                                                                                          |
| payple       | 페이플                 | 실시간 계좌이체                                                                                      |
| alipay       | 알리페이                | 신용카드                                                                                          |
| bluewalnut   | 블루월넛                | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제                                                                |
| tosspay      | 토스 - 간편결제           | 신용카드                                                                                          |                                                                                           |
| smartro      | 스마트로                | 신용카드, 가상계좌, 실시간 계좌이체                                                                          |
| tosspayments | 토스페이먼츠              | 신용카드                                                                                          |

==> iamport_flutter-0.10.17.tar.gz: SUPPORT.md <==
# 지원정보

아임포트 플러터 모듈이 지원하는 PG사 및 결제수단 안내입니다.

| pg           | 이름                  | 결제수단                                                                                          |
|--------------|---------------------|-----------------------------------------------------------------------------------------------|
| html5_inicis | 웹 표준 이니시스           | 신용카드, 가상계좌, 실시간 계좌이체(IOS 별도 설정 필요), 휴대폰 소액결제, 삼성페이, KPAY, 문화상품권, 스마트문상, 해피머니                  |
| kcp          | NHN KCP             | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제, 삼성페이                                                          |
| kcp_billing  | NHN KCP 정기결제        | 신용카드                                                                                          |
| uplus        | 토스페이먼츠 - (구)LG 유플러스 | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제, 문화상품권, 스마트문상, 도서상푼권                                           |        
| jtnet        | JTNET               | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제                                                                |
| nice         | 나이스 정보통신            | 신용카드, 가상계좌, 실시간 계좌이체(IOS/안드로이드 별도 설정 필요), 휴대폰 소액결제                                            |
| kakaopay     | 신 - 카카오페이           | 신용카드                                                                                          |
| kakao        | 구 - LG CNS 카카오페이    | 신용카드                                                                                          |
| danal        | 다날 휴대폰 소액결제         | 휴대폰 소액결제                                                                                      |
| danal_tpay   | 다날 일반결제             | 신용카드, 가상계좌, 실시간 계좌이체                                                                          |
| kicc         | 한국정보통신              | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제                                                                |
| paypal       | 페이팔                 | 신용카드                                                                                          |
| mobilians    | 모빌리언스               | 신용카드, 가상계좌(준비중), 실시간 계좌이체(준비중), 휴대폰 소액결제                                                      |
| payco        | 페이코                 | 신용카드                                                                                          |
| eximbay      | 엑심베이                | 신용카드 [주의사항](https://github.com/iamport/iamport-react-native/issues/70#issuecomment-704601908) |
| settle       | 세틀뱅크                | 가상계좌                                                                                          |
| naverco      | 네이버 체크아웃            | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제                                                                |
| naverpay     | 네이버페이               | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제                                                                |
| smilepay     | 스마일페이               | 신용카드 [주의사항](https://github.com/iamport/iamport-react-native/issues/71)                        |
| chai         | 차이페이                | 신용카드                                                                                          |
| payple       | 페이플                 | 실시간 계좌이체                                                                                      |
| alipay       | 알리페이                | 신용카드                                                                                          |
| bluewalnut   | 블루월넛                | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제                                                                |
| tosspay      | 토스 - 간편결제           | 신용카드                                                                                          |                                                           
| smartro      | 스마트로                | 신용카드, 가상계좌, 실시간 계좌이체                                                                          |
| tosspayments | 토스페이먼츠              | 신용카드                                                                                          |
| welcome      | 웰컴페이먼츠              | 신용카드, 가상계좌, 실시간 계좌이체, 휴대폰 소액결제, 문화상품권                                                         |
